@@ -1,6 +1,6 @@
 ;;; consult-register.el --- Consult commands for registers -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2025 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2026 Free Software Foundation, Inc.
 
 ;; This file is part of GNU Emacs.
 
@@ -19,7 +19,8 @@
 
 ;;; Commentary:
 
-;; Provides register-related Consult commands.
+;; Provides the register-related commands `consult-register',
+;; `consult-register-load' and `consult-register-store'.
 
 ;;; Code:
 
@@ -84,18 +85,19 @@ Each element of the list must have the form (char . name).")
 
 (cl-defmethod consult-register--describe ((val (head file)))
   "Describe file register VAL."
-  (list (propertize (abbreviate-file-name (cdr val)) 'face 'consult-file)
+  (list (propertize (consult--fast-abbreviate-file-name (cdr val)) 'face 'consult-file)
         'consult--type ?f 'multi-category `(file . ,(cdr val))))
 
 (cl-defmethod consult-register--describe ((val (head buffer)))
   "Describe buffer register VAL."
-  (list (propertize (cdr val) 'face 'consult-buffer)
-        'consult--type ?f 'multi-category `(buffer . ,(cdr val))))
+  (let ((buf (cdr val)))
+    (list (propertize (if (bufferp buf) (buffer-name buf) buf) 'face 'consult-buffer)
+          'consult--type ?f 'multi-category `(buffer . ,buf))))
 
 (cl-defmethod consult-register--describe ((val (head file-query)))
   "Describe file-query register VAL."
   (list (format "%s at position %d"
-                (propertize (abbreviate-file-name (cadr val))
+                (propertize (consult--fast-abbreviate-file-name (cadr val))
                             'face 'consult-file)
                 (caddr val))
         'consult--type ?f 'multi-category `(file . ,(cadr val))))
@@ -176,7 +178,7 @@ Raise an error if the list is empty and NOERROR is nil."
                      ;; Sometimes, registers are made without a `cdr' or with
                      ;; invalid markers.  Such registers don't do anything, and
                      ;; can be ignored.
-                     if (when-let ((val (cdr reg)))
+                     if (when-let* ((val (cdr reg)))
                           (and (or (not (markerp val)) (marker-buffer val))
                                (or (not pred) (funcall pred val))))
                      collect reg)
@@ -209,7 +211,7 @@ built-in register access functions.  The command supports narrowing, see
       (lambda (action cand)
         ;; Preview only markers
         (funcall preview action
-                 (when-let (reg (get-register cand))
+                 (when-let* ((reg (get-register cand)))
                    (and (markerp reg) reg)))))
     :group (consult--type-group consult-register--narrow)
     :narrow (consult--type-narrow consult-register--narrow)
@@ -249,7 +251,7 @@ This function is derived from `register-read-with-preview'."
           (lambda ()
             (unless (get-buffer-window buffer)
               (register-preview buffer 'show-empty)
-              (when-let (win (get-buffer-window buffer))
+              (when-let* ((win (get-buffer-window buffer)))
                 (with-selected-window win
                   (let ((inhibit-read-only t))
                     (goto-char (point-max))
@@ -322,7 +324,7 @@ kmacro."
     (t
      `("Store"
        (?p "point" "Point to register: " ,#'point-to-register)
-       ,@(when-let ((file (or buffer-file-name default-directory)))
+       ,@(when-let* ((file (or buffer-file-name default-directory)))
           `((?f "file" "File to register: " ,(lambda (r) (set-register r `(file . ,file))))))
        (?b "buffer" "Buffer to register: " ,(lambda (r) (set-register r `(buffer . ,(buffer-name)))))
        (?t "frameset" "Frameset to register: " ,#'frameset-to-register)
